##
##  postgresql-hll.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         postgresql-hll
Summary:      PostgreSQL Extension: HyperLogLog (HLL)
URL:          https://github.com/citusdata/postgresql-hll
Vendor:       CitusData
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      Apache
Version:      2.17
Release:      20221116

#   list of sources
Source0:      https://github.com/citusdata/postgresql-hll/archive/v%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  postgresql
PreReq:       postgresql

%description
    This adds a HyperLogLog (hll) data type to PostgreSQL. HyperLogLog
    is a fixed-size, set-like structure used for distinct value counting
    with tunable precision. For example, in 1280 bytes hll can estimate
    the count of tens of billions of distinct values with only a few
    percent error.

%track
    prog postgresql-hll = {
        version   = %{version}
        url       = https://github.com/citusdata/postgresql-hll/releases
        regex     = v(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n postgresql-hll-%{version}

%build
    %{l_make} %{l_mflags} \
        USE_PGXS=1 \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O}" \
        CPPFLAGS="%{l_cppflags}" \
        LDFLAGS="%{l_ldflags}" \
        hll.so

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/postgresql \
        $RPM_BUILD_ROOT%{l_prefix}/share/postgresql/extension
    %{l_shtool} install -c -m 644 \
        hll.so \
        $RPM_BUILD_ROOT%{l_prefix}/lib/postgresql/
    %{l_shtool} install -c -m 644 \
        hll.control \
        $RPM_BUILD_ROOT%{l_prefix}/share/postgresql/extension/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

